@@ -84,7 +84,7 @@ class GSCNodeFunctionCallerSocket:
             if (type(message) is dict):
                 self.oncnodefunctionanswer(self.gsdbs, message)
             else:
-                self.oncnodefunctionanswer(self.gsdbs, ubjson.loadb(message))
+                self.oncnodefunctionanswer(self.gsdbs, msgpack.unpackb(message, raw=False))
 
         connectURL = ""
 
